stage1_2/stage1_2.hh
changeset 867 a435684a5223
parent 746 c7219a37cc39
child 873 dea39ef02847
--- a/stage1_2/stage1_2.hh	Sat Feb 15 23:58:16 2014 +0000
+++ b/stage1_2/stage1_2.hh	Sun Feb 16 00:37:40 2014 +0000
@@ -57,12 +57,10 @@
 		/* Version 1.0 – Official Release                     */
 		/******************************************************/
 	bool safe_extensions;
-		/* error messages specify full token location */
-	bool full_token_loc; 
-		/* Include directory, where included files will be searched for... */
-	bool conversion_functions;
-		/* Create a conversion function for derived datatype */
-	const char *includedir;
+	bool full_token_loc;       /* error messages specify full token location */
+	bool conversion_functions; /* Create a conversion function for derived datatype */
+	bool nested_comments;      /* Allow the use of nested comments. */
+	const char *includedir;    /* Include directory, where included files will be searched for... */
 } stage1_2_options_t;